@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
+import json
 import logging
 import traceback
+from threading import Thread
+
 import pika
+from pika.exceptions import StreamLostError
 from concurrent.futures import ThreadPoolExecutor
 from typing import Callable, Union
-from pika.exceptions import StreamLostError
-from .rabbit_keys import RabbitKeys
 from ..util.decator import singleton
+from .rabbit_keys import RabbitKeys
 from .processor import AbstractMessageProcess
 from .processor import AbstractStreamMessageProcess
 
@@ -31,7 +34,6 @@ class BatchResultReceiver(object):
         self.inactivity_timeout = inactivity_timeout or 1800
         self.executor = ThreadPoolExecutor(max_workers=max_workers)
 
-        self.connection = pika.BlockingConnection(pika.URLParameters(self.rabbit_uri))
         LOGGER.info(f'[采集结果]监听器初始化 rabbit_uri={self.rabbit_uri}')
 
     def submit_receiving_task(self, app_code: str, tenant_code: str, batch_id: str):
@@ -54,7 +56,8 @@ class BatchResultReceiver(object):
         _routing_name = RabbitKeys.get_result_routing_key(app_code, batch_id)
         _queue_name = RabbitKeys.get_result_queue_key(app_code, batch_id)
 
-        channel = self.connection.channel()
+        connection = pika.BlockingConnection(pika.URLParameters(self.rabbit_uri))
+        channel = connection.channel()
         try:
             # 定义
             channel.queue_declare(queue=_queue_name, auto_delete=True, arguments={'x-expires': self.queue_expires * 1000})
@@ -72,7 +75,9 @@ class BatchResultReceiver(object):
                         LOGGER.error(f'[消息接收]消息结构异常 properties={properties}, body={body}')
                         continue
                     # 消息解析处理
-                    _process_func(headers.get('msg_type', None), body.decode(), tenant_code, batch_id)
+                    msg_type = headers.get('msg_type', None)
+                    body_json = json.loads(body.decode())
+                    _process_func(msg_type, body_json, tenant_code, batch_id)
                 except (StreamLostError, ConnectionAbortedError):
                     LOGGER.error(f'[消息接收]服务端关闭链接通道 batch_id={batch_id}')
                 except Exception:
@@ -85,6 +90,8 @@ class BatchResultReceiver(object):
             try:
                 # 关闭链接和通道（链接关闭通道自动关闭）
                 channel.close()
+                connection.close()
+                LOGGER.info(f'[消息接收]销毁队列 batch_id={batch_id}, queue={_queue_name}')
             except Exception:
                 LOGGER.error(f'[消息接收]关闭链接异常 queue={_queue_name}, {traceback.format_exc()}')
 
@@ -100,19 +107,20 @@ class StreamResultReceiver(object):
     3、通道按批次区分
     """
 
-    def __init__(self, processor: Union[AbstractStreamMessageProcess, Callable], rabbit_uri: str, qos: int = None, queue_expires: int = None, inactivity_timeout: int = None, max_workers: int = None):
+    def __init__(self, processor: Union[AbstractStreamMessageProcess, Callable], rabbit_uri: str, queue_expires: int = None, max_workers: int = None):
         self.processor = processor
         self.rabbit_uri = rabbit_uri
-        self.qos = qos or 10
         self.queue_expires = queue_expires or 28800
-        self.inactivity_timeout = inactivity_timeout or 1800
         self.executor = ThreadPoolExecutor(max_workers=max_workers)
-
         self.connection = pika.BlockingConnection(pika.URLParameters(self.rabbit_uri))
         LOGGER.info(f'[流采结果]监听器初始化 rabbit_uri={self.rabbit_uri}')
 
     def start(self, exchange_name: str, routing_name: str, queue_name: str):
-        self.executor.submit(self._receive_message, exchange_name, routing_name, queue_name)
+        Thread(
+            name='stream-receive',
+            target=self._receive_message,
+            kwargs={'exchange_name': exchange_name, 'routing_name': routing_name, 'queue_name': queue_name}
+        ).start()
 
     def _receive_message(self, exchange_name: str, routing_name: str, queue_name: str):
         """
@@ -133,7 +141,7 @@ class StreamResultReceiver(object):
             channel.queue_bind(queue=queue_name, exchange=exchange_name, routing_key=routing_name)
             LOGGER.info(f'[流采结果]队列信息 queue={queue_name}, exchange={exchange_name}, routing={routing_name}')
             # 接收
-            for method, properties, body in channel.consume(queue_name, inactivity_timeout=self.inactivity_timeout, auto_ack=False):
+            for method, properties, body in channel.consume(queue_name, auto_ack=False):
                 # 通道无活动消息一定时间后，自动终止消费（退出循环）
                 if not method and not properties:
                     break
@@ -142,8 +150,10 @@ class StreamResultReceiver(object):
                     if not headers:
                         LOGGER.error(f'[流采结果]消息结构异常 properties={properties}, body={body}')
                         continue
-                    # 消息解析处理
-                    _process_func(headers.get('msg_type', None), body.decode())
+                    # 消息解析并发处理
+                    msg_type = headers.get('msg_type', None)
+                    body_json = json.loads(body.decode())
+                    self.executor.submit(_process_func, msg_type, body_json)
                 except (StreamLostError, ConnectionAbortedError):
                     LOGGER.error(f'[流采结果]服务端关闭链接通道')
                 except Exception:
@@ -156,11 +166,17 @@ class StreamResultReceiver(object):
             try:
                 # 关闭链接和通道（链接关闭通道自动关闭）
                 channel.close()
+                LOGGER.info(f'[流采结果]销毁队列')
             except Exception:
                 LOGGER.error(f'[流采结果]关闭链接异常 {traceback.format_exc()}')
 
         LOGGER.info(f'[流采结果]接收完成')
 
+    def _try_reconnect(self):
+        if not self.connection or not self.connection.is_open:
+            self.connection = pika.BlockingConnection(pika.URLParameters(self.rabbit_uri))
+        channel = self.connection.channel()
+        return channel
 
 # @singleton
 # class StreamResultReceiver(object):
